@@ -82,7 +82,7 @@ class pdtLocale_base(object):
         # Used to parse expressions like "in 5 hours"
         self.numbers = { 'zero': 0, 'one': 1, 'two': 2, 'three': 3, 'four': 4,
                          'five': 5, 'six': 6, 'seven': 7, 'eight': 8, 'nine': 9,
-                         'ten': 10, 'eleven': 11, 'twelve': 12, 'thirtheen': 13,
+                         'ten': 10, 'eleven': 11, 'twelve': 12, 'thirteen': 13,
                          'fourteen': 14, 'fifteen': 15, 'sixteen': 16,
                          'seventeen': 17, 'eighteen': 18, 'nineteen': 19,
                          'twenty': 20 }
@@ -164,7 +164,10 @@ class pdtLocale_icu(pdtLocale_base):
         if self.icu is not None:
             # grab spelled out format of all numbers from 0 to 100
             rbnf = pyicu.RuleBasedNumberFormat(pyicu.URBNFRuleSetTag.SPELLOUT, self.icu)
-            self.numbers = dict([(rbnf.format(i), i) for i in xrange(0, 100)])
+            try:
+                self.numbers = dict([(rbnf.format(i), i) for i in xrange(0, 100)])
+            except NameError:
+                self.numbers = dict([(rbnf.format(i), i) for i in range(0, 100)])
 
             self.symbols = pyicu.DateFormatSymbols(self.icu)
 
